==> midgard2-core_9.03.0-5.tar.gz: midgard2-core-9.03.0/src/midgard_core_object_class.h <==
/* 
 * Copyright (C) 2006 Piotr Pokora <piotrek.pokora@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MIDGARD_CORE_OBJECT_CLASS_H
#define MIDGARD_CORE_OBJECT_CLASS_H

#include "midgard_object.h"
#include "schema.h"

gboolean		midgard_core_object_is_valid				(MgdObject *object);
void 			midgard_core_object_class_set_sitegroup_and_guid	(GObject *object, guint sg, const gchar *guid);
void			midgard_core_object_class_set_midgard			(MidgardConnection *mgd, GObject *object);
MgdSchemaTypeAttr 	*midgard_core_class_get_type_attr			(MidgardDBObjectClass *klass);
const gchar 		*midgard_core_class_get_table				(MidgardDBObjectClass *klass);
const gchar 		*midgard_core_class_get_tables				(MidgardDBObjectClass *klass);
MgdSchemaPropertyAttr 	*midgard_core_class_get_property_attr			(MidgardDBObjectClass *klass, const gchar *name);
const gchar 		*midgard_core_class_get_property_table			(MidgardDBObjectClass *klass, const gchar *name);
const gchar 		*midgard_core_class_get_property_colname		(MidgardDBObjectClass *klass, const gchar *name);
const gchar 		*midgard_core_class_get_property_tablefield		(MidgardDBObjectClass *klass, const gchar *name);

#endif /* MIDGARD_CORE_OBJECT_CLASS_H */

==> midgard2-core_9.09.orig.tar.gz: midgard2-core-9.09/src/midgard_core_object_class.h <==
/* 
 * Copyright (C) 2006 Piotr Pokora <piotrek.pokora@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MIDGARD_CORE_OBJECT_CLASS_H
#define MIDGARD_CORE_OBJECT_CLASS_H

#include "midgard_object.h"
#include "schema.h"

gboolean		midgard_core_object_is_valid				(MgdObject *object);
void 			midgard_core_object_class_set_guid			(GObject *object, const gchar *guid);
void			midgard_core_object_class_set_midgard			(MidgardConnection *mgd, GObject *object);
MgdSchemaTypeAttr 	*midgard_core_class_get_type_attr			(MidgardDBObjectClass *klass);
const gchar 		*midgard_core_class_get_table				(MidgardDBObjectClass *klass);
const gchar 		*midgard_core_class_get_tables				(MidgardDBObjectClass *klass);
MgdSchemaPropertyAttr 	*midgard_core_class_get_property_attr			(MidgardDBObjectClass *klass, const gchar *name);
const gchar 		*midgard_core_class_get_property_table			(MidgardDBObjectClass *klass, const gchar *name);
const gchar 		*midgard_core_class_get_property_colname		(MidgardDBObjectClass *klass, const gchar *name);
const gchar 		*midgard_core_class_get_property_tablefield		(MidgardDBObjectClass *klass, const gchar *name);

#endif /* MIDGARD_CORE_OBJECT_CLASS_H */
